Method: Pod::DSLError#dsl_path

Defined in:
lib/cocoapods-core/standard_error.rb

#dsl_pathString (readonly)

Returns the path of the dsl file that raised the exception.

Returns:

  • (String)

    the path of the dsl file that raised the exception.



18
19
20
# File 'lib/cocoapods-core/standard_error.rb', line 18

def dsl_path
  @dsl_path
end