Method: Pod::Podfile::DSL#plugin

Defined in:
lib/cocoapods-core/podfile/dsl.rb

#plugin(name, options = {}) ⇒ void

This method returns an undefined value.

Specifies the plugins that should be used during installation.


Use this method to specify a plugin that should be used during installation, along with the options that should be passed to the plugin when it is invoked.

Examples:

Specifying to use the slather and cocoapods-keys plugins.


plugin 'cocoapods-keys', :keyring => 'Eidolon'
plugin 'slather'


919
920
921
922
923
# File 'lib/cocoapods-core/podfile/dsl.rb', line 919

def plugin(name, options = {})
  hash_plugins = get_hash_value('plugins') || {}
  (hash_plugins[name] ||= {}).merge!(options.deep_stringify_keys)
  set_hash_value('plugins', hash_plugins)
end