Returns The podfile that contains the specification for this target definition.
Returns:
The podfile that contains the specification for this target definition.
63 64 65
# File 'lib/cocoapods-core/podfile/target_definition.rb', line 63 def podfile root.parent end