Method: Pod::Podfile::TargetDefinition#user_project_path

Defined in:
lib/cocoapods-core/podfile/target_definition.rb

#user_project_pathString

Returns the path of the project this target definition should link with.

Returns:

  • (String)

    the path of the project this target definition should link with.



242
243
244
245
246
247
248
249
# File 'lib/cocoapods-core/podfile/target_definition.rb', line 242

def user_project_path
  path = get_hash_value('user_project_path')
  if path
    Pathname(path).sub_ext('.xcodeproj').to_path
  else
    parent.user_project_path unless root?
  end
end