Method: Pod::Podfile::TargetDefinition#uses_frameworks?

Defined in:
lib/cocoapods-core/podfile/target_definition.rb

#uses_frameworks?Boolean

Returns whether the target definition pods should be built as frameworks.

Returns:

  • (Boolean)

    whether the target definition pods should be built as frameworks.



411
412
413
414
415
416
417
# File 'lib/cocoapods-core/podfile/target_definition.rb', line 411

def uses_frameworks?
  if internal_hash['uses_frameworks'].nil?
    root? ? false : parent.uses_frameworks?
  else
    build_type.framework?
  end
end