Method: Pod::Source::Manager#all

Defined in:
lib/cocoapods-core/source/manager.rb

#allArray<Source>

Returns The list of all the sources known to this installation of CocoaPods.

Returns:

  • (Array<Source>)

    The list of all the sources known to this installation of CocoaPods.



59
60
61
# File 'lib/cocoapods-core/source/manager.rb', line 59

def all
  aggregate.sources
end