Method: Pod::Source#fuzzy_search

Defined in:
lib/cocoapods-core/source.rb

#fuzzy_search(query) ⇒ Set, Nil

Returns the set of the Pod whose name fuzzily matches the given query.

Parameters:

  • query (String)

    The query to search for.

Returns:

  • (Set)

    The name of the Pod.

  • (Nil)

    If no Pod with a suitable name was found.



333
334
335
336
337
338
339
# File 'lib/cocoapods-core/source.rb', line 333

def fuzzy_search(query)
  require 'fuzzy_match'
  pod_name = FuzzyMatch.new(pods).find(query)
  if pod_name
    search(pod_name)
  end
end