Method: Pod::Specification::Set::Presenter#authors

Defined in:
lib/cocoapods-core/specification/set/presenter.rb

#authorsString

Returns the list of the authors of the Pod in sentence format.

Examples:

Output example


"Author 1, Author 2 and Author 3"

Returns:

  • (String)

    the list of the authors of the Pod in sentence format.



88
89
90
91
# File 'lib/cocoapods-core/specification/set/presenter.rb', line 88

def authors
  return '' unless spec.authors
  spec.authors.keys.to_sentence
end