Method: Pod::Version#semantic?

Defined in:
lib/cocoapods-core/version.rb

#semantic?Boolean

Note:

This comparison is lenient.

Note:

It doesn’t support build identifiers.

Returns Whether the version conforms to the Semantic Versioning specification (2.0.0-rc.1).

Returns:

  • (Boolean)

    Whether the version conforms to the Semantic Versioning specification (2.0.0-rc.1).



96
97
98
# File 'lib/cocoapods-core/version.rb', line 96

def semantic?
  version.to_s =~ ANCHORED_SEMANTIC_VERSION_PATTERN
end