Method: Pod::Specification::DSL#default_subspecs=

Defined in:
lib/cocoapods-core/specification/dsl.rb

#default_subspecs=(subspec_array) ⇒ Object

An array of subspecs names that should be used as preferred dependency. If not specified, a specification requires all of its subspecs as dependencies.

You may use the value :none to specify that none of the subspecs are required to compile this pod and that all subspecs are optional.


A Pod should make available the full library by default. Users can fine tune their dependencies, and exclude unneeded subspecs, once their requirements are known. Therefore, this attribute is rarely needed. It is intended to be used to select a default if there are ‘sub-specifications’ which provide alternative incompatible implementations, or to exclude modules rarely needed (especially if they trigger dependencies on other libraries).

Examples:


spec.default_subspec = 'Core'

spec.default_subspecs = 'Core', 'UI'

spec.default_subspecs = :none

Parameters:

  • subspec_names (Array<String>, String, Symbol)

    An array of subspec names that should be inherited as dependency.



1826
1827
1828
1829
# File 'lib/cocoapods-core/specification/dsl.rb', line 1826

root_attribute :default_subspecs,
:container => Array,
:types => [Array, String, Symbol],
:singularize => true