Module: Pod::Vendor::Gem
- Defined in:
- lib/cocoapods-core/vendor.rb
Overview
Namespaces the classes of RubyGems used by CocoaPods.
CocoaPods needs to vendor RubyGems because OS X ships with v1.3.6 which has a couple of bugs related to the comparison of pre-release versions.
E.g. github.com/CocoaPods/CocoaPods/issues/398
The following classes are copied from RubyGems v2.6.3. The changes performed to the source files are the following:
-
Namespaced in
Pod::Vendor -
commented all the
requirecalls -
replaced
::GemwithPod::Vendor::Gem
Defined Under Namespace
Classes: Requirement, Version