Method: Pod::Podfile::DSL#podspec
- Defined in:
- lib/cocoapods-core/podfile/dsl.rb
#podspec(options = nil) ⇒ void
Note:
This method uses the dependencies declared for the platform of the target definition.
Note:
This method requires that the Podfile has a non nil value for Pod::Podfile#defined_in_file unless the path option is used.
This method returns an undefined value.
Use just the dependencies of a Pod defined in the given podspec file. If no arguments are passed the first podspec in the root of the Podfile is used. It is intended to be used by the project of a library. Note: this does not include the sources derived from the podspec just the CocoaPods infrastructure.
343 344 345 |
# File 'lib/cocoapods-core/podfile/dsl.rb', line 343 def podspec( = nil) current_target_definition.store_podspec() end |