Method: Pod::Source#specs_dir
- Defined in:
- lib/cocoapods-core/source.rb
#specs_dir ⇒ Pathname
Note:
In previous versions of CocoaPods they used to be stored in the root of the repo. This lead to issues, especially with the GitHub interface and now they are stored in a dedicated folder.
Returns The directory where the specs are stored.
97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cocoapods-core/source.rb', line 97 def specs_dir @specs_dir ||= begin specs_sub_dir = repo + 'Specs' if specs_sub_dir.exist? specs_sub_dir elsif repo.exist? repo end end end |